==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/fi.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Pyyntötunnisteen nouto epäonnistui. Tarkista että sovellusavaimesi ja -salaisuutesi ovat oikein.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Pyyntötunnisteen haku epäonnistui. Tarkista että sovellusavaimesi ja -salaisuutesi ovat oikein.",
    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
    "Step 1 failed. Exception: %s" : "Vaihe 1 epäonnistui. Poikkeus: %s",
    "Step 2 failed. Exception: %s" : "Vaihe 2 epäonnistui. Poikkeus: %s",
    "External storages" : "Ulkoiset tallennustilat",
    "Dropbox App Configuration" : "Dropbox-sovelluksen määritys",
    "Google Drive App Configuration" : "Google Drive -sovelluksen määritys",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(group)" : "(ryhmä)",
    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
    "Admin defined" : "Ylläpitäjän määrittämä",
    "Saved" : "Tallennettu",
    "Saving..." : "Tallennetaan...",
    "Save" : "Tallenna",
    "Empty response from the server" : "Tyhjä vastaus palvelimelta",
    "Couldn't get the information from the remote server: {code} {type}" : "Tietojen saaminen etäpalvelimelta epäonnistui: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Erillisten liitospisteiden listauksen noutaminen epäonnistui: {type}",
    "There was an error with message: " : "Tapahtui virhe viestillä:",
    "External mount error" : "Ulkoinen liitosvirhe",
    "external-storage" : "ulkoinen taltio",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Jotkin määritetyt erilliset liitospisteet eivät ole yhdistettynä. Napsauta punaisia rivejä saadaksesi lisätietoja",
    "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Credentials saved" : "Kirjautumistiedot tallennettu",
    "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
    "Credentials required" : "Kirjautumistiedot vaaditaan",
    "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
    "Invalid backend or authentication mechanism class" : "Virheellinen tietovarasto tai tunnistautumismekanismin luokka",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "Objectstore forbidden" : "Objektimuisti estetty",
    "Invalid storage backend \"%s\"" : "Virheellinen tietovarasto \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ei lupaa käyttää tietovarastoa \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ei lupaa käyttää tunnistautumismekanismia  \"%s\"",
    "Unsatisfied backend parameters" : "Riittämättömät tietovaraston parametrit",
    "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
    "Insufficient data: %s" : "Puutteellinen data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
    "Access key" : "Pääsyavain",
    "Secret key" : "Salainen avain",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant nimi",
    "Identity endpoint URL" : "Määritä URL-päätepiste",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Global credentials" : "Globaalit valtuudet",
    "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Isäntänimi",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "Enable Path Style" : "Aktivoi polun tyyli",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juurihakemisto",
    "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaa",
    "Domain" : "Domaini",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää asentamaan puuttuva kohde.",
    "External storage support" : "Ulkoisen taltion tuki",
    "No external storage configured" : "Erillistä tallennustilaa ei ole määritetty",
    "You can add external storages in the personal settings" : "Voit lisätä erillisiä tallennustiloja henkilökohtaisista asetuksistasi",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "Scope" : "Näkyvyysalue",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Enable sharing" : "Käytä jakamista",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "Folder name" : "Kansion nimi",
    "External storage" : "Ulkoinen tallennustila",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Add storage" : "Lisää tallennustila",
    "Advanced settings" : "Lisäasetukset",
    "Delete" : "Poista",
    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
    "Allow users to mount the following external storage" : "Salli käyttäjien liittää seuraavat erilliset tallennusvälineet",
    "Storage with id \"%i\" not found" : "Tallennustilaa tunnisteella \"%i\" ei löytynyt",
    "Storage with id \"%i\" is not user editable" : "Tallennustila, jolla on \"%i\" id, ei ole muokattavissa."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/fi.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Ulkoiset tallennustilat",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(group)" : "(ryhmä)",
    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
    "Admin defined" : "Ylläpitäjän määrittämä",
    "Are you sure you want to delete this external storage" : "Haluatko varmasti poistaa tämän erillisen tallennustilan",
    "Delete storage?" : "Poistetaanko tallennustila?",
    "Saved" : "Tallennettu",
    "Saving..." : "Tallennetaan...",
    "Save" : "Tallenna",
    "Empty response from the server" : "Tyhjä vastaus palvelimelta",
    "Couldn't access. Please log out and in again to activate this mount point" : "Käyttö ei onnistunut. Kirjaudu ulos ja takaisin sisään aktivoidaksesi tämän liitoskohdan",
    "Couldn't get the information from the remote server: {code} {type}" : "Tietojen saaminen etäpalvelimelta epäonnistui: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Erillisten liitospisteiden listauksen noutaminen epäonnistui: {type}",
    "There was an error with message: " : "Tapahtui virhe viestillä:",
    "External mount error" : "Ulkoinen liitosvirhe",
    "external-storage" : "ulkoinen taltio",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ei voitu noutaa listaa Windows-verkkoasemien liitoskohdista: tyhjä vastaus palvelimelta",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Jotkin määritetyt erilliset liitospisteet eivät ole yhdistettynä. Napsauta punaisia rivejä saadaksesi lisätietoja",
    "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Credentials saved" : "Kirjautumistiedot tallennettu",
    "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
    "Credentials required" : "Kirjautumistiedot vaaditaan",
    "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
    "Invalid backend or authentication mechanism class" : "Virheellinen tietovarasto tai tunnistautumismekanismin luokka",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "Objectstore forbidden" : "Objektimuisti estetty",
    "Invalid storage backend \"%s\"" : "Virheellinen tallennustilan taustaosa \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ei lupaa käyttää tietovarastoa \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ei lupaa käyttää tunnistautumismekanismia  \"%s\"",
    "Unsatisfied backend parameters" : "Riittämättömät tietovaraston parametrit",
    "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
    "Insufficient data: %s" : "Puutteellinen data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
    "Access key" : "Pääsyavain",
    "Secret key" : "Salainen avain",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant nimi",
    "Identity endpoint URL" : "Määritä URL-päätepiste",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Global credentials" : "Globaalit valtuudet",
    "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Isäntänimi",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "Enable Path Style" : "Aktivoi polun tyyli",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juurihakemisto",
    "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaa",
    "Domain" : "Domaini",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää asentamaan puuttuva kohde.",
    "No external storage configured" : "Erillistä tallennustilaa ei ole määritetty",
    "You can add external storages in the personal settings" : "Voit lisätä erillisiä tallennustiloja henkilökohtaisista asetuksistasi",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "Scope" : "Näkyvyysalue",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Enable sharing" : "Käytä jakamista",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "Folder name" : "Kansion nimi",
    "External storage" : "Ulkoinen tallennustila",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Add storage" : "Lisää tallennustila",
    "Advanced settings" : "Lisäasetukset",
    "Delete" : "Poista",
    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
    "Allow users to mount the following external storage" : "Salli käyttäjien liittää seuraavat erilliset tallennusvälineet",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Pyyntötunnisteen nouto epäonnistui. Tarkista että sovellusavaimesi ja -salaisuutesi ovat oikein.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Pyyntötunnisteen haku epäonnistui. Tarkista että sovellusavaimesi ja -salaisuutesi ovat oikein.",
    "Step 1 failed. Exception: %s" : "Vaihe 1 epäonnistui. Poikkeus: %s",
    "Step 2 failed. Exception: %s" : "Vaihe 2 epäonnistui. Poikkeus: %s",
    "Dropbox App Configuration" : "Dropbox-sovelluksen määritys",
    "Google Drive App Configuration" : "Google Drive -sovelluksen määritys",
    "Storage with id \"%i\" not found" : "Tallennustilaa tunnisteella \"%i\" ei löytynyt",
    "Storage with id \"%i\" is not user editable" : "Tallennustila, jolla on \"%i\" id, ei ole muokattavissa.",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
